aboutsummaryrefslogtreecommitdiffstats
path: root/addon/randplace/randplace.php
diff options
context:
space:
mode:
authorroot <root@diekershoff.homeunix.net>2010-12-25 09:24:24 +0100
committerroot <root@diekershoff.homeunix.net>2010-12-25 09:24:24 +0100
commitc5cf9de32a247bbb1757b1f8e30ab3483544fa31 (patch)
tree5681ebeadd2e3ad079c8b33ba5e8be90f9d6fb4f /addon/randplace/randplace.php
parent6f8c4169e57188093b3d2ce6d0e66f1364b5a5fb (diff)
parent7382c353e521f36db2d40ac9aa2b3ca14cc64369 (diff)
downloadvolse-hubzilla-c5cf9de32a247bbb1757b1f8e30ab3483544fa31.tar.gz
volse-hubzilla-c5cf9de32a247bbb1757b1f8e30ab3483544fa31.tar.bz2
volse-hubzilla-c5cf9de32a247bbb1757b1f8e30ab3483544fa31.zip
Merge branch 'master' of git://github.com/friendika/friendika
Diffstat (limited to 'addon/randplace/randplace.php')
-rw-r--r--addon/randplace/randplace.php17
1 files changed, 9 insertions, 8 deletions
diff --git a/addon/randplace/randplace.php b/addon/randplace/randplace.php
index e14ae74c7..2e1bd33ac 100644
--- a/addon/randplace/randplace.php
+++ b/addon/randplace/randplace.php
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
* Then we'll attach into the settings page, on both the
* form and post hooks so that we can create and update
* user preferences.
*
*/
- register_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ register_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
register_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
logger("installed randplace");
@@ -60,7 +60,7 @@ function randplace_uninstall() {
*/
unregister_hook('post_local', 'addon/randplace/randplace.php', 'randplace_post_hook');
- unregister_hook('settings_form', 'addon/randplace/randplace.php', 'randplace_settings');
+ unregister_hook('plugin_settings', 'addon/randplace/randplace.php', 'randplace_settings');
unregister_hook('settings_post', 'addon/randplace/randplace.php', 'randplace_settings_post');
@@ -142,7 +142,8 @@ function randplace_settings_post($a,$post) {
/**
* Called from the end of the settings form.
* Add our own settings info to the page.
*
*/
@@ -154,7 +155,7 @@ function randplace_settings(&$a,&$s) {
if(! local_user())
return;
- /* Add our stylesheet so we can match the page layout */
+ /* Add our stylesheet to the page so we can make our settings look nice */
$a->page['htmlhead'] .= '<link rel="stylesheet" type="text/css" href="' . $a->get_baseurl() . '/addon/randplace/randplace.css' . '" media="all" />' . "\r\n";
@@ -164,7 +165,7 @@ function randplace_settings(&$a,&$s) {
$checked = (($enabled) ? ' checked="checked" ' : '');
- /* Add some HTML to the form */
+ /* Add some HTML to the existing form */
$s .= '<h3>' . t('Randplace Settings') . '</h3>';
$s .= '<div id="randplace-enable-wrapper">';
@@ -172,7 +173,7 @@ function randplace_settings(&$a,&$s) {
$s .= '<input id="randplace-checkbox" type="checkbox" name="randplace" value="1" ' . $checked . '/>';
$s .= '</div><div class="clear"></div>';
- /* provide another submit button */
+ /* provide a submit button */
$s .= '<div class="settings-submit-wrapper" ><input type="submit" name="submit" class="settings-submit" value="' . t('Submit') . '" /></div>';
@@ -36,13 +36,13 @@ function randplace_install() {
/**
*
- * Then we'll attach into the settings page, on both the
- * form and post hooks so that we can create and update
+ * Then we'll attach into the plugin settings page, and also the
+ * settings post hook so that we can create and update
* user preferences.
*
@@ -142,7 +142,8 @@ function randplace_settings_post($a,$post) {
/**
- * Called from the end of the settings form.
+ *
+ * Called from the Plugin Setting form.
* Add our own settings info to the page.
*